/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the NCD N102 Norwegian keyboard.
 * By Bj|rn Wennberg <bjornw@edb.tih.no>
 */

static const KeyCode ncd102n_codes [] = {

  /* Row 0 */
  8,
  66, 67, 68, 69,
  70, 71, 72, 73,
  74, 75, 94, 95,
  110, 77, 109,

  /* Row 2 */
  48, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
  105, 96, 98,
  76, 111, 62, 81,

  /* Row 3 */
  22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
  35,
  106, 102, 104,
  78, 79, 80, 85,

  /* Row 4 */
  65, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 50,
  82, 83, 84,
  
  /* Row 5 */
  49, 93, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61,
  97,
  86, 87, 88, 107,
  
  /* Row 6 */
  36,
  63, 64, 112,
  108,
  99, 103, 101,
  89, 90
};
